@@ -1,15 +1,14 @@
+# Available imports to be used dinamically in the API spec
+import datetime  # noqa: F401
 import logging
+import math  # noqa: F401
+import random  # noqa: F401
 import re
+import time  # noqa: F401
+import uuid  # noqa: F401
 
 from scanapi.errors import InvalidPythonCodeError
 
-# Available imports to be used dinamically in the API spec
-import datetime
-import math
-import random
-import time
-import uuid
-
 logger = logging.getLogger(__name__)
 
 
