@@ -1,10 +1,12 @@
-from itertools import chain
 import logging
+from itertools import chain
 
 from scanapi.evaluators import SpecEvaluator
 from scanapi.exit_code import ExitCode
 from scanapi.session import session
+from scanapi.tree.request_node import RequestNode
 from scanapi.tree.tree_keys import (
+    DELAY_KEY,
     ENDPOINTS_KEY,
     HEADERS_KEY,
     NAME_KEY,
@@ -14,7 +16,6 @@ from scanapi.tree.tree_keys import (
     ROOT_SCOPE,
     VARS_KEY,
 )
-from scanapi.tree.request_node import RequestNode
 from scanapi.utils import join_urls, validate_keys
 
 logger = logging.getLogger(__name__)
@@ -29,6 +30,7 @@ class EndpointNode:
         PARAMS_KEY,
         PATH_KEY,
         REQUESTS_KEY,
+        DELAY_KEY,
     )
     REQUIRED_KEYS = (NAME_KEY,)
     ROOT_REQUIRED_KEYS = ()
@@ -44,7 +46,8 @@ class EndpointNode:
         self._validate()
 
         self.child_nodes = [
-            EndpointNode(spec, parent=self) for spec in self.spec.get(ENDPOINTS_KEY, [])
+            EndpointNode(spec, parent=self)
+            for spec in self.spec.get(ENDPOINTS_KEY, [])
         ]
 
     def __repr__(self):
@@ -74,6 +77,11 @@ class EndpointNode:
     def params(self):
         return self._get_specs(PARAMS_KEY)
 
+    @property
+    def delay(self):
+        delay = self.spec.get(DELAY_KEY, 0)
+        return delay or getattr(self.parent, DELAY_KEY, 0)
+
     @property
     def is_root(self):
         return not self.parent
@@ -83,9 +91,7 @@ class EndpointNode:
             try:
                 yield request.run()
             except Exception as e:
-                error_message = (
-                    f"\nError to make request `{request.full_url_path}`. \n{str(e)}\n"
-                )
+                error_message = f"\nError to make request `{request.full_url_path}`. \n{str(e)}\n"
                 logger.error(error_message)
                 session.exit_code = ExitCode.REQUEST_ERROR
                 continue
@@ -114,6 +120,9 @@ class EndpointNode:
 
     def _get_requests(self):
         return chain(
-            (RequestNode(spec, self) for spec in self.spec.get(REQUESTS_KEY, [])),
+            (
+                RequestNode(spec, self)
+                for spec in self.spec.get(REQUESTS_KEY, [])
+            ),
             *(child._get_requests() for child in self.child_nodes),
         )
